@@ -272,7 +272,7 @@ class Biglist(Sequence):
                 path = LocalUpath(path.absolute())
             if keep_files is None:
                 keep_files = True
-        if path.is_dir() and list(path.iterdir()):
+        if path.is_dir() and not path.is_empty_dir():
             raise Exception(f'directory "{path}" already exists')
 
         obj = cls(path, **kwargs)  # type: ignore
@@ -476,7 +476,7 @@ class Biglist(Sequence):
 
     def __len__(self) -> int:
         z = self.get_data_files()
-        return sum(k for _, k in z)
+        return sum(k for _, k in z) + len(self._append_buffer)
 
     def append(self, x) -> None:
         '''
@@ -727,6 +727,10 @@ class ListView(Sequence):
             for i in self._range:
                 yield self._list[i]
 
+    @property
+    def raw(self):
+        return self._list
+
 
 Biglist.register_storage_format('json', JsonSerializer)
 Biglist.register_storage_format('pickle-z', CompressedPickleSerializer)
